@@ -16,8 +16,17 @@ print.coda = function(x, ..., basis = getOption('coda.base.basis')){
   print.methods.list = utils::methods('print')
   orig_class = setdiff(class(x.print), 'coda')
   class(x.print) = orig_class
-  print.method = match(paste0('print.',orig_class), print.methods.list)[1]
+  print.method = stats::na.omit(match(paste0('print.',orig_class), print.methods.list))[1]
   if(!basis) attr(x.print, 'basis') = NULL
-  if(is.na(print.method)) print.default(x.print, ...)
-  else utils::getAnywhere(print.methods.list[print.method])$objs[[1]](x.print, ...)
+  if(is.na(print.method)){
+    print.default(x.print, ...)
+  }else{
+    utils::getAnywhere(print.methods.list[print.method])$objs[[1]](x.print, ...)
+    if(basis){
+      B = attr(x.print, 'basis')
+      dimnames(B) = list(paste0('P', 1:nrow(B)), colnames(x))
+      cat(' Basis:\n')
+      print(B)
+    }
+  }
 }
